import os
import json

def process_file(file_path, category_name):
    """
    处理单个分类文件，将其转换为 shopdata 的结构
    """
    with open(file_path, "r", encoding="utf-8") as f:
        data = json.load(f)
    
    category_type = "Buy" if "buy" in data else "Sell"
    category_key = "buy" if "buy" in data else "sell"

    category = {
        "name": category_name,
        "type": "group",
        "image": "textures/items/book_portfolio.png",
        "data": []
    }

    for item in data[category_key]:
        # 去除 "minecraft:" 前缀
        item_id = item["id"].replace("minecraft:", "") if "minecraft:" in item["id"] else item["id"]

        category["data"].append({
            "name": item["name"],
            "type": "exam",
            "image": "",
            "data": {
                "type": f"minecraft:{item_id}",  # 商品 ID 已去除前缀
                "aux": item.get("aux", 0),
                "remark": "",
                "money": item["price"]
            }
        })

    return category_type, category

def merge_shopdata(output_file="shopdata.json"):
    """
    合并当前工作目录下的所有分类 JSON 文件到 shopdata.json
    """
    shopdata = {"Buy": [], "Sell": []}

    for file_name in os.listdir():
        # 跳过 config.json 和非 JSON 文件
        if file_name == "config.json" or not file_name.endswith(".json"):
            continue

        # 提取分类名
        if "_" in file_name:
            category_name = file_name.split("_")[1].replace(".json", "")
        else:
            category_name = file_name.replace(".json", "")  # 文件名即为分类名

        # 处理文件内容
        category_type, category_data = process_file(file_name, category_name)
        shopdata[category_type].append(category_data)
    
    # 输出整合后的 shopdata.json
    with open(output_file, "w", encoding="utf-8") as f:
        json.dump(shopdata, f, ensure_ascii=False, indent=4)
    print(f"Shopdata has been successfully saved to {output_file}")

if __name__ == "__main__":
    merge_shopdata()
